# The Race (yachting race)

From Wikipedia, the free encyclopedia

The Race was a round-the-world sailing race starting in Barcelona, Spain on December 31, 2000. It was the first ever non-stop, no-rules, no-limits, round-the-world sailing event, with a $2 million US prize. It was organized by Bruno Peyron.

The stated objectives of this race were:

- to unite the different maritime cultures of the world
- to gather together the world's premiere yachtsmen and women in a common event
- to promote creativity in ocean sailing
- to ally high technology and the environment
- to create the most spectacular and most prestigious fleet of offshore racers that sailing has ever seen

A second race was planned for 2004, but was cancelled amid controversy that Tracy Edwards had organized a competing event called Oryx Quest.

## Results[edit]

The 2000–01 race was won by Club Med, skippered by Grant Dalton in 62d 6h 56' 33".

Pos | Boat | Crew | Country | Time
--- | --- | --- | --- | ---
1 | Club Med | Dalton, Grant Grant Dalton | New Zealand | 62d 6h 56m 33s
2 | Innovation Explorer | Peyron, Loick Loick Peyron & Skip Novak | France | 64d 22h 32m 38s
3 | Team Adventure | Lewis, Cam Cam Lewis | United States | 82d 20h 21m 02s
4 | Warta Polpharma | Paszke, Roman Roman Paszke | Poland | 99d 12h 31m
5 | Team Legato | Bullimore, Tony Tony Bullimore | Great Britain | 104d 20h 52m
- | PlayStation | Fossett, Steve Steve Fossett | United States | DNF[a]
- | Team Philips | Goss, Pete Pete Goss | Great Britain | DNS

1. ^ Damaged and forced to withdraw on day 16

Legend: DNF – Did not finish; DNS – Did not start;